@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package OpenAPI::Modern; # git description: v0.031-9-g4672327
+package OpenAPI::Modern; # git description: v0.032-3-g53dadc7
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Validate HTTP requests and responses against an OpenAPI document
 # KEYWORDS: validation evaluation JSON Schema OpenAPI Swagger HTTP request response
 
-our $VERSION = '0.032';
+our $VERSION = '0.033';
 
 use 5.020;
 use Moo;
@@ -696,7 +696,7 @@ OpenAPI::Modern - Validate HTTP requests and responses against an OpenAPI docume
 
 =head1 VERSION
 
-version 0.032
+version 0.033
 
 =head1 SYNOPSIS
 
@@ -773,8 +773,8 @@ version 0.032
 prints:
 
   request:
-  at '/request/body/hello': got integer, not string
-  at '/request/body': not all properties are valid
+  '/request/body/hello': got integer, not string
+  '/request/body': not all properties are valid
 
   {
     "errors" : [
@@ -999,7 +999,7 @@ Only certain permutations of OpenAPI documents are supported at this time:
 
 =item *
 
-for all parameters types, only C<explode: true> is supported
+for all parameter types, only C<explode: true> is supported
 
 =item *
 
